==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/security/kotlin/outputs/AllowlistCustomAlertRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * A custom alert rule that checks if a value (depends on the custom alert type) is allowed.
 * @property allowlistValues The values to allow. The format of the values depends on the rule type.
 * @property description The description of the custom alert.
 * @property displayName The display name of the custom alert.
 * @property isEnabled Status of the custom alert.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'AllowlistCustomAlertRule'.
 * @property valueType The value type of the items in the list.
 */
public data class AllowlistCustomAlertRuleResponse(
    public val allowlistValues: List<String>,
    public val description: String,
    public val displayName: String,
    public val isEnabled: Boolean,
    public val ruleType: String,
    public val valueType: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.security.outputs.AllowlistCustomAlertRuleResponse):
            AllowlistCustomAlertRuleResponse = AllowlistCustomAlertRuleResponse(
            allowlistValues = javaType.allowlistValues().map({ args0 -> args0 }),
            description = javaType.description(),
            displayName = javaType.displayName(),
            isEnabled = javaType.isEnabled(),
            ruleType = javaType.ruleType(),
            valueType = javaType.valueType(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/security/kotlin/outputs/AllowlistCustomAlertRuleResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.security.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * A custom alert rule that checks if a value (depends on the custom alert type) is allowed.
 * @property allowlistValues The values to allow. The format of the values depends on the rule type.
 * @property description The description of the custom alert.
 * @property displayName The display name of the custom alert.
 * @property isEnabled Status of the custom alert.
 * @property ruleType The type of the custom alert rule.
 * Expected value is 'AllowlistCustomAlertRule'.
 * @property valueType The value type of the items in the list.
 */
public data class AllowlistCustomAlertRuleResponse(
    public val allowlistValues: List<String>,
    public val description: String,
    public val displayName: String,
    public val isEnabled: Boolean,
    public val ruleType: String,
    public val valueType: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.security.outputs.AllowlistCustomAlertRuleResponse): AllowlistCustomAlertRuleResponse = AllowlistCustomAlertRuleResponse(
            allowlistValues = javaType.allowlistValues().map({ args0 -> args0 }),
            description = javaType.description(),
            displayName = javaType.displayName(),
            isEnabled = javaType.isEnabled(),
            ruleType = javaType.ruleType(),
            valueType = javaType.valueType(),
        )
    }
}
